'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _testUtils = require('testUtils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getComponent = function getComponent() {
  return require('ui/box/header').default;
};

describe('Header', function () {
  var Header = void 0;

  beforeEach(function () {
    Header = getComponent();
  });

  it('renders correctly with basic props', function () {
    var props = {
      title: 'This is the header',
      name: 'Header',
      logoUrl: 'some-logo.png',
      backgroundUrl: 'some-image.png',
      backgroundColor: 'red'
    };

    (0, _testUtils.expectComponent)(_react2.default.createElement(Header, props)).toMatchSnapshot();
  });

  it('shows the back button when there is a handler', function () {
    var props = {
      title: 'This is the header',
      name: 'Header',
      logoUrl: 'some-logo.png',
      backgroundUrl: 'some-image.png',
      backgroundColor: 'red',
      backHandler: function backHandler() {
        return jest.fn();
      }
    };

    (0, _testUtils.expectComponent)(_react2.default.createElement(Header, props)).toMatchSnapshot();
  });

  it('shows the logoUrl when there is no name', function () {
    var props = {
      title: 'This is the header',
      backgroundUrl: 'some-image.png',
      logoUrl: 'some-logo.png',
      backgroundColor: 'red'
    };

    (0, _testUtils.expectComponent)(_react2.default.createElement(Header, props)).toMatchSnapshot();
  });

  it('sets the header size property on the document element', function () {
    var spy = jest.spyOn(document.documentElement.style, 'setProperty');

    var props = {
      title: 'This is the header',
      name: 'Header',
      logoUrl: 'some-logo.png',
      backgroundUrl: 'some-image.png',
      backgroundColor: 'red'
    };

    (0, _testUtils.expectComponent)(_react2.default.createElement(Header, props), {
      createNodeMock: function createNodeMock() {
        return { clientHeight: 100 };
      }
    }).toMatchSnapshot();

    expect(spy).toHaveBeenCalledWith('--header-height', '100px');
  });
});
